==> tdm_2.1.1.tar.gz: tdm/R/all.Amidihirsm.R <==
all.Amidihirsm<-function(){
     cat("\n")                                                                       
     cat("-------------------------------------------------------------\n")
     cat("    --Aminophylline dihydrous IR input data information--    \n")
     note_for_Theirsm_input()
     cat("-------------------------------------------------------------\n") 
     cat("\n")
     note_for_close_window()
     AmidihirSMMpar<-data.frame(parameter=c("Gender","age (yr)","ht (cm)","CHF","smoke","D (mg)","tau (hr)"),value=c(0))
     AmidihirSMMpar<-edit(AmidihirSMMpar)
     AmidihirSMMpar<-ycheck(AmidihirSMMpar)
     cat("\n")
     cat("-------------------------------------------------------------\n")
     cat("    --Aminophylline dihydrous IR input data information--    \n")
     note_for_Thesm_conc_input()
     cat("-------------------------------------------------------------\n")
     cat("\n")
     note_for_close_window()
     AmidihirSMpar<-data.frame(ts=c(0),conc=c(0))                                                                                                                             
     AmidihirSMpar<-edit(AmidihirSMpar)                                            
     AmidihirSMpar<-mscheck(AmidihirSMpar)                                         
     cat("\n")
     Amidihir.sm(length(AmidihirSMpar$ts),AmidihirSMpar$conc,AmidihirSMpar$ts,AmidihirSMMpar[7,2],AmidihirSMMpar[6,2],AmidihirSMMpar[3,2],AmidihirSMMpar[2,2],AmidihirSMMpar[5,2],AmidihirSMMpar[1,2],AmidihirSMMpar[4,2])
     note_for_convergence_plots()
     convergence_plots_sep()
     cat("------------------------------------------------------------------\n")
     cat("    --Aminophylline dihydrous IR input data information--         \n")
     note_for_Theirsm_output()
     cat("------------------------------------------------------------------\n")
     show(samplesStats("*"))
     cat("\n")
     r=log(1.85-(samplesStats("cl_F")/samplesStats("v_F")))/(1.85-(samplesStats("cl_F")/samplesStats("v_F")))
     C<-TheIRsscpr(0.8,AmidihirSMMpar[6,2],AmidihirSMMpar[7,2],r)
     sim<-matrix(C[1 ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Cpss_pr (mg/L)")
     output1<-coutput
     show(coutput) 
     C<-TheIRsscpr(0.8,AmidihirSMMpar[6,2],AmidihirSMMpar[7,2],AmidihirSMMpar[7,2])
     sim<-matrix(C[1 ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Ctss_pr (mg/L)")
     output2<-coutput
     show(coutput)     
     cat("\n")   
     Amidihir.more()                   
}

==> tdm_2.2.6.tar.gz: tdm/R/all.Amidihirsm.R <==
all.Amidihirsm<-function(){
     cat("\n")                                                                       
     cat("-------------------------------------------------------------\n")
     cat("    --Aminophylline dihydrous IR input data information--    \n")
     note_for_Theirsm_input()
     cat("-------------------------------------------------------------\n") 
     cat("\n")
     note_for_close_window()
     AmidihirSMMpar<-data.frame(parameter=c("Gender","age (yr)","ht (cm)","CHF","smoke","D (mg)","tau (hr)"),value=c(0))
     AmidihirSMMpar<-edit(AmidihirSMMpar)
##     AmidihirSMMpar<-ycheck(AmidihirSMMpar)
     cat("\n")
     cat("-------------------------------------------------------------\n")
     cat("    --Aminophylline dihydrous IR input data information--    \n")
     note_for_Thesm_conc_input()
     cat("-------------------------------------------------------------\n")
     cat("\n")
     note_for_close_window()
     AmidihirSMpar<-data.frame(ts=c(0),conc=c(0))                                                                                                                             
     AmidihirSMpar<-edit(AmidihirSMpar)                                            
     AmidihirSMpar<-mscheck(AmidihirSMpar)                                         
     cat("\n")
     Amidihir.sm(length(AmidihirSMpar$ts),AmidihirSMpar$conc,AmidihirSMpar$ts,AmidihirSMMpar[7,2],AmidihirSMMpar[6,2],AmidihirSMMpar[3,2],AmidihirSMMpar[2,2],AmidihirSMMpar[5,2],AmidihirSMMpar[1,2],AmidihirSMMpar[4,2])
     note_for_convergence_plots()
     convergence_plots_sep()
     cat("------------------------------------------------------------------\n")
     cat("    --Aminophylline dihydrous IR input data information--         \n")
     note_for_Theirsm_output()
     cat("------------------------------------------------------------------\n")
     show(samplesStats("*"))
     cat("\n")
     r=log(1.85-(samplesStats("cl_F")/samplesStats("v_F")))/(1.85-(samplesStats("cl_F")/samplesStats("v_F")))
     C<-TheIRsscpr(0.8,AmidihirSMMpar[6,2],AmidihirSMMpar[7,2],r)
     sim<-matrix(C[1 ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Cpss_pr (mg/L)")
     output1<-coutput
     show(coutput) 
     C<-TheIRsscpr(0.8,AmidihirSMMpar[6,2],AmidihirSMMpar[7,2],AmidihirSMMpar[7,2])
     sim<-matrix(C[1 ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Ctss_pr (mg/L)")
     output2<-coutput
     show(coutput)     
     cat("\n")   
     Amidihir.more()                   
}
